@@ -11,12 +11,15 @@ class Column(object):
     header_template = 'header_column.html'
     creation_counter = 0
 
-    def __init__(self, label, refname=None, sortable=False, order_by=None, **attrs):
+    def __init__(self, label, refname=None, sortable=False, order_by=None,
+                 header_style=None, cell_style=None, **attrs):
         self.name = None #fills by table metaclass
         self.label = label
         self.refname = refname
         self.sortable = sortable
         self.order_by = order_by
+        self.header_style = header_style
+        self.cell_style = cell_style
         self.attrs = attrs
 
         self.creation_counter = Column.creation_counter
